@@ -509,6 +509,13 @@ def cfv_cftypehelp_test(s,o,expected):
 			return 'type %s not found in output'%tname
 	return 0
 
+def cfv_nooutput_test(s,o,expected=0):
+	if s!=expected:
+		return 1
+	if o:
+		return 'output: %s'%(repr(o),)
+	return 0
+
 def T_test(f, extra=None):
 	cmd=cfvcmd
 	if extra:
@@ -1073,7 +1080,22 @@ def test_encoding2():
 	shutil.rmtree(unicode(d))
 	
 
-def largefile_test():
+def largefile2GB_test():
+	# hope you have sparse file support ;)
+	fn = os.path.join('bigfile2','bigfile')
+	f = open(fn,'wb')
+	try:
+		f.write('hi')
+		f.seek(2**30)
+		f.write('foo')
+		f.seek(2**31)
+		f.write('bar')
+		f.close()
+		test_generic(cfvcmd+" -v -T -p %s"%('bigfile2'), rcurry(cfv_all_test,ok=6))
+	finally:
+		os.unlink(fn)
+
+def largefile4GB_test():
 	# hope you have sparse file support ;)
 	fn = os.path.join('bigfile','bigfile')
 	f = open(fn,'wb')
@@ -1156,6 +1178,23 @@ def specialfile_test(cfpath):
 		shutil.rmtree(d)
 	
 
+def private_torrent_test():
+	cmd=cfvcmd
+	tmpd = mkdtemp()
+	try:
+		needle = '7:privatei1'
+		f = os.path.join(tmpd, 'test.torrent')
+		test_generic("%s -C -f %s data1"%(cmd,f),cfv_test)
+		data = readfile(f)
+		test_log_results('should not contain private flag', 0, repr(data), needle in data, None)
+
+		f = os.path.join(tmpd, 'test2.torrent')
+		test_generic("%s --private_torrent -C -f %s data1"%(cmd,f),cfv_test)
+		data = readfile(f)
+		test_log_results('should contain private flag', 0, repr(data), needle not in data, None)
+	finally:
+		shutil.rmtree(tmpd)
+
 
 cfvenv=''
 cfvexe=os.path.join(os.pardir,'cfv')
@@ -1200,7 +1239,7 @@ if args:
 	cfvexe=args[0]
 
 #set everything to default in case user has different in config file
-cfvcmd='-ZNVRMUI --unquote=no --fixpaths="" --strippaths=0 --showpaths=auto-relative --progress=no --announceurl=url'
+cfvcmd='-ZNVRMUI --unquote=no --fixpaths="" --strippaths=0 --showpaths=auto-relative --progress=no --announceurl=url --noprivate_torrent'
 
 if run_internal:
 	runcfv = runcfv_py
@@ -1340,6 +1379,7 @@ def all_tests():
 	C_test("csv2","-t csv2")
 	C_test("csv4","-t csv4")
 	C_test("crc")
+	private_torrent_test()
 	#test_generic("../cfv -V -T -f test.md5",cfv_test)
 	#test_generic("../cfv -V -tcsv -T -f test.md5",cfv_test)
 	for t in allfmts():
@@ -1391,12 +1431,16 @@ def all_tests():
 			shutil.rmtree(d)
 
 	if run_long_tests:
-		largefile_test()
+		largefile2GB_test()
+		largefile4GB_test()
 	
-	test_generic(cfvcmd+" -t aoeu",rcurry(cfv_cftypehelp_test,1))
-	test_generic(cfvcmd+" -t help",rcurry(cfv_cftypehelp_test,0))
+	test_generic(cfvcmd+" -t aoeu",rcurry(cfv_cftypehelp_test,1),stdout='/dev/null')
+	test_generic(cfvcmd+" -t aoeu",rcurry(cfv_nooutput_test,1),stderr='/dev/null')
+	test_generic(cfvcmd+" -t help",rcurry(cfv_cftypehelp_test,0),stderr='/dev/null')
+	test_generic(cfvcmd+" -t help",rcurry(cfv_nooutput_test,0),stdout='/dev/null')
 
-	test_generic(cfvcmd+" -h",cfv_version_test)
+	test_generic(cfvcmd+" -h",cfv_nooutput_test,stdout='/dev/null')
+	test_generic(cfvcmd+" -h",cfv_version_test,stderr='/dev/null')
 
 	donestr="tests finished:  ok: %i  failed: %i"%(stats.ok,stats.failed)
 	log("\n"+donestr)
